@@ -56,16 +56,17 @@ __defineGetter__("PlacesUtils", function() {
 
 const LOAD_IN_SIDEBAR_ANNO = "bookmarkProperties/loadInSidebar";
 const DESCRIPTION_ANNO = "bookmarkProperties/description";
+const GUID_ANNO = "placesInternal/GUID";
 const LMANNO_FEEDURI = "livemark/feedURI";
 const LMANNO_SITEURI = "livemark/siteURI";
 const ORGANIZER_FOLDER_ANNO = "PlacesOrganizer/OrganizerFolder";
 const ORGANIZER_QUERY_ANNO = "PlacesOrganizer/OrganizerQuery";
 const ORGANIZER_LEFTPANE_VERSION = 4;
 
-//@line 70 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 71 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
 // On other platforms, the transferable system converts "\r\n" to "\n".
 const NEWLINE = "\r\n";
-//@line 73 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 74 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
 
 function QI_node(aNode, aIID) {
   return aNode.QueryInterface(aIID);
@@ -202,11 +203,13 @@ var PlacesUIUtils = {
     var itemTitle = aData.title;
     var keyword = aData.keyword || null;
     var annos = aData.annos || [];
-    if (aExcludeAnnotations) {
-      annos = annos.filter(function(aValue, aIndex, aArray) {
-        return aExcludeAnnotations.indexOf(aValue.name) == -1;
-      });
-    }
+    // always exclude GUID when copying any item
+    var excludeAnnos = [GUID_ANNO];
+    if (aExcludeAnnotations)
+      excludeAnnos = excludeAnnos.concat(aExcludeAnnotations);
+    annos = annos.filter(function(aValue, aIndex, aArray) {
+      return excludeAnnos.indexOf(aValue.name) == -1;
+    });
     var childTxns = [];
     if (aData.dateAdded)
       childTxns.push(this.ptm.editItemDateAdded(null, aData.dateAdded));
@@ -297,6 +300,10 @@ var PlacesUIUtils = {
         childItems.push(this.ptm.editItemLastModified(null, aData.lastModified));
 
       var annos = aData.annos || [];
+      annos = annos.filter(function(aAnno) {
+        // always exclude GUID when copying any item
+        return aAnno.name != GUID_ANNO;
+      });
       return this.ptm.createFolder(aData.title, aContainer, aIndex, annos, childItems);
     }
   },
@@ -316,8 +323,9 @@ var PlacesUIUtils = {
         siteURI = PlacesUtils._uri(aAnno.value);
         return false;
       }
-      return true;
-    }, this);
+      // always exclude GUID when copying any item
+      return aAnno.name != GUID_ANNO;
+    });
     return this.ptm.createLivemark(feedURI, siteURI, aData.title, aContainer,
                                    aIndex, aData.annos);
   },
@@ -356,10 +364,8 @@ var PlacesUIUtils = {
         if (copy) {
           // Copying a child of a live-bookmark by itself should result
           // as a new normal bookmark item (bug 376731)
-          var copyBookmarkAnno =
-            this._getBookmarkItemCopyTransaction(data, container, index,
-                                                 ["livemark/bookmarkFeedURI"]);
-          return copyBookmarkAnno;
+          return this._getBookmarkItemCopyTransaction(data, container, index,
+                                                      ["livemark/bookmarkFeedURI"]);
         }
         else
           return this.ptm.moveItem(data.id, container, index);
@@ -710,9 +716,9 @@ var PlacesUIUtils = {
 
     var features;
     if (aMinimalUI)
-//@line 720 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 726 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
       features = "centerscreen,chrome,dialog,resizable,dependent";
-//@line 722 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 728 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
     else
       features = "centerscreen,chrome,modal,resizable=no";
     window.openDialog(dialogURL, "",  features, aInfo);
@@ -1005,10 +1011,10 @@ var PlacesUIUtils = {
         var popup = document.createElement("menupopup");
         popup.setAttribute("placespopup", "true");
         popup._resultNode = asContainer(aNode);
-//@line 1015 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 1021 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
         // no context menu on mac
         popup.setAttribute("context", "placesContext");
-//@line 1018 "/home/gscrivano/icecat/301/browser/components/places/content/utils.js"
+//@line 1024 "/icecat-3.0.5-g1/browser/components/places/content/utils.js"
         element.appendChild(popup);
         if (aContainersMap)
           aContainersMap.push({ resultNode: aNode, domNode: popup });
