@@ -1,4 +1,4 @@
-//@line 46 "/mnt/data/211/toolkit/content/finddialog.js"
+//@line 46 "/icecat-3.0.5-g1/toolkit/content/finddialog.js"
 
 var dialog;     // Quick access to document/form elements.
 var gFindInst;   // nsIWebBrowserFind that we're going to use
@@ -36,7 +36,7 @@ function fillDialog()
   // this is necessary for window.find()
   dialog.findKey.value           = gFindInst.searchString ? gFindInst.searchString : findService.searchString;
   dialog.caseSensitive.checked   = gFindInst.matchCase ? gFindInst.matchCase : findService.matchCase;
-  // Don't initialize Wrap here, we just want it to be checked. 
+  dialog.wrap.checked            = gFindInst.wrapFind ? gFindInst.wrapFind : findService.wrapFind;
   var findBackwards              = gFindInst.findBackwards ? gFindInst.findBackwards : findService.findBackwards;
   if (findBackwards)
     dialog.rg.selectedItem = dialog.up;
